@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -270,9 +270,9 @@ class CodeMetricsDialog(QDialog, Ui_CodeMetricsDialog):
                                    self.__data)
         filterList = filterString.split(",")
         if filterList:
-            for filter in filterList:
+            for filterString in filterList:
                 fileList = [f for f in fileList
-                            if not fnmatch.fnmatch(f, filter.strip())]
+                            if not fnmatch.fnmatch(f, filterString.strip())]
         
         self.resultList.clear()
         self.summaryList.clear()
