@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 
@@ -20,7 +20,7 @@ from PyQt5.QtCore import pyqtSignal, pyqtSlot, Qt, QFile, QIODevice, QUrl, \
 from PyQt5.QtWidgets import QWidget, QDialogButtonBox, QAbstractButton, \
     QTreeWidgetItem, QDialog, QVBoxLayout, QMenu
 from PyQt5.QtNetwork import QNetworkAccessManager, QNetworkRequest, \
-    QNetworkReply
+    QNetworkReply, QNetworkConfigurationManager
 
 from .Ui_PluginRepositoryDialog import Ui_PluginRepositoryDialog
 
@@ -123,6 +123,17 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
             self.__networkManager.sslErrors.connect(self.__sslErrors)
         self.__replies = []
         
+        if Preferences.getUI("DynamicOnlineCheck"):
+            self.__networkConfigurationManager = \
+                QNetworkConfigurationManager(self)
+            self.__onlineStateChanged(
+                self.__networkConfigurationManager.isOnline())
+            self.__networkConfigurationManager.onlineStateChanged.connect(
+                self.__onlineStateChanged)
+        else:
+            self.__networkConfigurationManager = None
+            self.__onlineStateChanged(True)
+        
         self.__doneMethod = None
         self.__inDownload = False
         self.__pluginsToDownload = []
@@ -134,6 +145,34 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         
         self.__populateList()
     
+    @pyqtSlot(bool)
+    def __onlineStateChanged(self, online):
+        """
+        Private slot handling online state changes.
+        
+        @param online flag indicating the online status
+        @type bool
+        """
+        self.__updateButton.setEnabled(online)
+        self.on_repositoryList_itemSelectionChanged()
+        if online:
+            msg = self.tr("Network Status: online")
+        else:
+            msg = self.tr("Network Status: offline")
+        self.statusLabel.setText(msg)
+    
+    def __isOnline(self):
+        """
+        Private method to check the online status.
+        
+        @return flag indicating the online status
+        @rtype bool
+        """
+        if self.__networkConfigurationManager is not None:
+            return self.__networkConfigurationManager.isOnline()
+        else:
+            return True
+    
     @pyqtSlot(QAbstractButton)
     def on_buttonBox_clicked(self, button):
         """
@@ -232,8 +271,12 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         """
         Private slot to handle a change of the selection.
         """
-        self.__downloadButton.setEnabled(len(self.__selectedItems()))
-        self.__downloadInstallButton.setEnabled(len(self.__selectedItems()))
+        self.__downloadButton.setEnabled(
+            len(self.__selectedItems()) and
+            self.__isOnline())
+        self.__downloadInstallButton.setEnabled(
+            len(self.__selectedItems()) and
+            self.__isOnline())
         self.__installButton.setEnabled(len(self.__selectedItems()))
     
     def __updateList(self):
@@ -395,26 +438,35 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         @param filename local name of the file (string)
         @param doneMethod method to be called when done
         """
-        self.__updateButton.setEnabled(False)
-        self.__downloadButton.setEnabled(False)
-        self.__downloadInstallButton.setEnabled(False)
-        self.__downloadCancelButton.setEnabled(True)
-        
-        self.statusLabel.setText(url)
-        
-        self.__doneMethod = doneMethod
-        self.__downloadURL = url
-        self.__downloadFileName = filename
-        self.__downloadIODevice = QFile(self.__downloadFileName + ".tmp")
-        self.__downloadCancelled = False
-        
-        request = QNetworkRequest(QUrl(url))
-        request.setAttribute(QNetworkRequest.CacheLoadControlAttribute,
-                             QNetworkRequest.AlwaysNetwork)
-        reply = self.__networkManager.get(request)
-        reply.finished.connect(self.__downloadFileDone)
-        reply.downloadProgress.connect(self.__downloadProgress)
-        self.__replies.append(reply)
+        if self.__isOnline():
+            self.__updateButton.setEnabled(False)
+            self.__downloadButton.setEnabled(False)
+            self.__downloadInstallButton.setEnabled(False)
+            self.__downloadCancelButton.setEnabled(True)
+            
+            self.statusLabel.setText(url)
+            
+            self.__doneMethod = doneMethod
+            self.__downloadURL = url
+            self.__downloadFileName = filename
+            self.__downloadIODevice = QFile(self.__downloadFileName + ".tmp")
+            self.__downloadCancelled = False
+            
+            request = QNetworkRequest(QUrl(url))
+            request.setAttribute(QNetworkRequest.CacheLoadControlAttribute,
+                                 QNetworkRequest.AlwaysNetwork)
+            reply = self.__networkManager.get(request)
+            reply.finished.connect(self.__downloadFileDone)
+            reply.downloadProgress.connect(self.__downloadProgress)
+            self.__replies.append(reply)
+        else:
+            E5MessageBox.warning(
+                self,
+                self.tr("Error downloading file"),
+                self.tr(
+                    """<p>Could not download the requested file"""
+                    """ from {0}.</p><p>Error: {1}</p>"""
+                ).format(url, self.tr("Computer is offline.")))
     
     def __downloadFileDone(self):
         """
@@ -423,7 +475,8 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         """
         self.__updateButton.setEnabled(True)
         self.__downloadCancelButton.setEnabled(False)
-        self.statusLabel.setText("  ")
+        self.__onlineStateChanged(
+            self.__isOnline())
         
         ok = True
         reply = self.sender()
@@ -577,12 +630,12 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         if not zipfile.is_zipfile(archive):
             return PluginRepositoryWidget.PluginStatusRemoteUpdate
         
-        zip = zipfile.ZipFile(archive, "r")
+        zipFile = zipfile.ZipFile(archive, "r")
         try:
-            aversion = zip.read("VERSION").decode("utf-8")
+            aversion = zipFile.read("VERSION").decode("utf-8")
         except KeyError:
             aversion = ""
-        zip.close()
+        zipFile.close()
         
         if aversion == version:
             if not self.__external:
@@ -590,7 +643,13 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
                 pluginManager = e5App().getObject("PluginManager")
                 pluginName = filename.rsplit('-', 1)[0]
                 pluginDetails = pluginManager.getPluginDetails(pluginName)
-                if pluginDetails is None or pluginDetails["version"] < version:
+                if pluginDetails is None:
+                    return PluginRepositoryWidget.PluginStatusLocalUpdate
+                if version.count(".") >= 3:
+                    # cope for extended version numbers by ignoring
+                    # the extension
+                    version = ".".join(version.split(".", 3)[:3])
+                if pluginDetails["version"] < version:
                     return PluginRepositoryWidget.PluginStatusLocalUpdate
             
             return PluginRepositoryWidget.PluginStatusUpToDate
