@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -12,7 +12,8 @@ from __future__ import unicode_literals
 import os
 import types
 
-from PyQt5.QtCore import QMetaObject, pyqtSignal, Qt, QRect, pyqtSlot
+from PyQt5.QtCore import QMetaObject, pyqtSignal, Qt, QRect, pyqtSlot, \
+    qVersion
 from PyQt5.QtGui import QPixmap
 from PyQt5.QtWidgets import QSizePolicy, QSpacerItem, QWidget, QTreeWidget, \
     QStackedWidget, QDialog, QSplitter, QScrollArea, QApplication, \
@@ -78,9 +79,11 @@ class ConfigurationWidget(QWidget):
     DefaultMode = 0
     HelpBrowserMode = 1
     TrayStarterMode = 2
+    HexEditorMode = 3
+    WebBrowserMode = 4
     
     def __init__(self, parent=None, fromEric=True, displayMode=DefaultMode,
-                 expandedEntries=[]):
+                 expandedEntries=None, webEngine=False):
         """
         Constructor
         
@@ -88,20 +91,26 @@ class ConfigurationWidget(QWidget):
         @keyparam fromEric flag indicating a dialog generation from within the
             eric6 ide (boolean)
         @keyparam displayMode mode of the configuration dialog
-            (DefaultMode, HelpBrowserMode, TrayStarterMode)
+            (DefaultMode, HelpBrowserMode, TrayStarterMode, HexEditorMode,
+             WebBrowserMode)
         @exception RuntimeError raised to indicate an invalid dialog mode
         @keyparam expandedEntries list of entries to be shown expanded
             (list of strings)
+        @keyparam webEngine flag indicating QtWebEngine is used (bool)
         """
         assert displayMode in (
             ConfigurationWidget.DefaultMode,
             ConfigurationWidget.HelpBrowserMode,
-            ConfigurationWidget.TrayStarterMode
+            ConfigurationWidget.TrayStarterMode,
+            ConfigurationWidget.HexEditorMode,
+            ConfigurationWidget.WebBrowserMode,
         )
         
         super(ConfigurationWidget, self).__init__(parent)
         self.fromEric = fromEric
         self.displayMode = displayMode
+        self.__webEngine = webEngine
+        expandedEntries = [] if expandedEntries is None else expandedEntries[:]
         
         self.__setupUi()
         
@@ -138,6 +147,9 @@ class ConfigurationWidget(QWidget):
                 "graphicsPage":
                 [self.tr("Graphics"), "preferences-graphics.png",
                  "GraphicsPage", None, None],
+                "hexEditorPage":
+                [self.tr("Hex Editor"), "hexEditor.png",
+                 "HexEditorPage", None, None],
                 "iconsPage":
                 [self.tr("Icons"), "preferences-icons.png",
                  "IconsPage", None, None],
@@ -277,27 +289,14 @@ class ConfigurationWidget(QWidget):
                 "0helpPage":
                 [self.tr("Help"), "preferences-help.png",
                  None, None, None],
-                "helpAppearancePage":
-                [self.tr("Appearance"), "preferences-styles.png",
-                 "HelpAppearancePage", "0helpPage", None],
                 "helpDocumentationPage":
                 [self.tr("Help Documentation"),
                  "preferences-helpdocumentation.png",
                  "HelpDocumentationPage", "0helpPage", None],
-                "helpFlashCookieManagerPage":
-                [self.tr("Flash Cookie Manager"),
-                 "flashCookie16.png",
-                 "HelpFlashCookieManagerPage", "0helpPage", None],
                 "helpViewersPage":
                 [self.tr("Help Viewers"),
                  "preferences-helpviewers.png",
                  "HelpViewersPage", "0helpPage", None],
-                "helpVirusTotalPage":
-                [self.tr("VirusTotal Interface"), "virustotal.png",
-                 "HelpVirusTotalPage", "0helpPage", None],
-                "helpWebBrowserPage":
-                [self.tr("eric6 Web Browser"), "ericWeb.png",
-                 "HelpWebBrowserPage", "0helpPage", None],
                 
                 "0projectPage":
                 [self.tr("Project"), "preferences-project.png",
@@ -323,6 +322,57 @@ class ConfigurationWidget(QWidget):
                 [self.tr("Viewmanager"), "preferences-viewmanager.png",
                  "ViewmanagerPage", "0interfacePage", None],
             }
+            if webEngine:
+                self.configItems.update({
+                    "0webBrowserPage":
+                    [self.tr("Web Browser"), "ericWeb.png",
+                     None, None, None],
+                    "webBrowserAppearancePage":
+                    [self.tr("Appearance"), "preferences-styles.png",
+                     "WebBrowserAppearancePage", "0webBrowserPage", None],
+                    "webBrowserPage":
+                    [self.tr("eric6 Web Browser"), "ericWeb.png",
+                     "WebBrowserPage", "0webBrowserPage", None],
+                    "helpFlashCookieManagerPage":
+                    [self.tr("Flash Cookie Manager"),
+                     "flashCookie16.png",
+                     "HelpFlashCookieManagerPage", "0webBrowserPage", None],
+                    "helpVirusTotalPage":
+                    [self.tr("VirusTotal Interface"), "virustotal.png",
+                     "HelpVirusTotalPage", "0webBrowserPage", None],
+                })
+                if qVersion() >= "5.8.0":
+                    self.configItems.update({
+                        "webBrowserSpellCheckingPage":
+                        [self.tr("Spell checking"),
+                         "preferences-spellchecking.png",
+                         "WebBrowserSpellCheckingPage", "0webBrowserPage",
+                         None],
+                    })
+            else:
+                try:
+                    from PyQt5 import QtWebKit      # __IGNORE_WARNING__
+                    self.configItems.update({
+                        "0helpBrowserPage":
+                        [self.tr("Web Browser"), "ericWeb.png",
+                         None, None, None],
+                        "helpAppearancePage":
+                        [self.tr("Appearance"), "preferences-styles.png",
+                         "HelpAppearancePage", "0helpBrowserPage", None],
+                        "helpWebBrowserPage":
+                        [self.tr("eric6 Web Browser"), "ericWeb.png",
+                         "HelpWebBrowserPage", "0helpBrowserPage", None],
+                        "helpFlashCookieManagerPage":
+                        [self.tr("Flash Cookie Manager"),
+                         "flashCookie16.png",
+                         "HelpFlashCookieManagerPage", "0helpBrowserPage",
+                         None],
+                        "helpVirusTotalPage":
+                        [self.tr("VirusTotal Interface"), "virustotal.png",
+                         "HelpVirusTotalPage", "0helpBrowserPage", None],
+                    })
+                except ImportError:
+                    pass
             
             self.configItems.update(
                 e5App().getObject("PluginManager").getPluginConfigData())
@@ -348,27 +398,80 @@ class ConfigurationWidget(QWidget):
                 [self.tr("Security"), "preferences-security.png",
                  "SecurityPage", None, None],
                 
-                "0helpPage":
-                [self.tr("Help"), "preferences-help.png",
-                 None, None, None],
-                "helpAppearancePage":
-                [self.tr("Appearance"), "preferences-styles.png",
-                 "HelpAppearancePage", "0helpPage", None],
                 "helpDocumentationPage":
                 [self.tr("Help Documentation"),
                  "preferences-helpdocumentation.png",
-                 "HelpDocumentationPage", "0helpPage", None],
+                 "HelpDocumentationPage", None, None],
+            }
+            try:
+                from PyQt5 import QtWebKit      # __IGNORE_WARNING__
+                self.configItems.update({
+                    "helpAppearancePage":
+                    [self.tr("Appearance"), "preferences-styles.png",
+                     "HelpAppearancePage", None, None],
+                    "helpFlashCookieManagerPage":
+                    [self.tr("Flash Cookie Manager"),
+                     "flashCookie16.png",
+                     "HelpFlashCookieManagerPage", None, None],
+                    "helpVirusTotalPage":
+                    [self.tr("VirusTotal Interface"), "virustotal.png",
+                     "HelpVirusTotalPage", None, None],
+                    "helpWebBrowserPage":
+                    [self.tr("eric6 Web Browser"), "ericWeb.png",
+                     "HelpWebBrowserPage", None, None],
+                })
+            except ImportError:
+                pass
+        
+        elif displayMode == ConfigurationWidget.WebBrowserMode:
+            self.configItems = {
+                # key : [display string, pixmap name, dialog module name or
+                #        page creation function, parent key,
+                #        reference to configuration page (must always be last)]
+                # The dialog module must have the module function 'create' to
+                # create the configuration page. This must have the method
+                # 'save' to save the settings.
+                "interfacePage":
+                [self.tr("Interface"), "preferences-interface.png",
+                 "HelpInterfacePage", None, None],
+                "networkPage":
+                [self.tr("Network"), "preferences-network.png",
+                 "NetworkPage", None, None],
+                "printerPage":
+                [self.tr("Printer"), "preferences-printer.png",
+                 "PrinterPage", None, None],
+                "securityPage":
+                [self.tr("Security"), "preferences-security.png",
+                 "SecurityPage", None, None],
+                
+                "helpDocumentationPage":
+                [self.tr("Help Documentation"),
+                 "preferences-helpdocumentation.png",
+                 "HelpDocumentationPage", None, None],
+                
+                "webBrowserAppearancePage":
+                [self.tr("Appearance"), "preferences-styles.png",
+                 "WebBrowserAppearancePage", None, None],
+                "webBrowserPage":
+                [self.tr("eric6 Web Browser"), "ericWeb.png",
+                 "WebBrowserPage", None, None],
+                
                 "helpFlashCookieManagerPage":
                 [self.tr("Flash Cookie Manager"),
                  "flashCookie16.png",
-                 "HelpFlashCookieManagerPage", "0helpPage", None],
+                 "HelpFlashCookieManagerPage", None, None],
                 "helpVirusTotalPage":
                 [self.tr("VirusTotal Interface"), "virustotal.png",
-                 "HelpVirusTotalPage", "0helpPage", None],
-                "helpWebBrowserPage":
-                [self.tr("eric6 Web Browser"), "ericWeb.png",
-                 "HelpWebBrowserPage", "0helpPage", None],
+                 "HelpVirusTotalPage", None, None],
             }
+            
+            if qVersion() >= "5.8.0":
+                self.configItems.update({
+                    "webBrowserSpellCheckingPage":
+                    [self.tr("Spell checking"),
+                     "preferences-spellchecking.png",
+                     "WebBrowserSpellCheckingPage", None, None],
+                })
         
         elif displayMode == ConfigurationWidget.TrayStarterMode:
             self.configItems = {
@@ -383,6 +486,19 @@ class ConfigurationWidget(QWidget):
                  "TrayStarterPage", None, None],
             }
         
+        elif displayMode == ConfigurationWidget.HexEditorMode:
+            self.configItems = {
+                # key : [display string, pixmap name, dialog module name or
+                #        page creation function, parent key,
+                #        reference to configuration page (must always be last)]
+                # The dialog module must have the module function 'create' to
+                # create the configuration page. This must have the method
+                # 'save' to save the settings.
+                "hexEditorPage":
+                [self.tr("Hex Editor"), "hexEditor.png",
+                 "HexEditorPage", None, None],
+            }
+        
         else:
             raise RuntimeError("Illegal mode value: {0}".format(displayMode))
         
@@ -414,7 +530,14 @@ class ConfigurationWidget(QWidget):
         self.buttonBox.accepted.connect(self.accept)
         self.buttonBox.rejected.connect(self.rejected)
         
-        if displayMode != ConfigurationWidget.TrayStarterMode:
+        if displayMode in [ConfigurationWidget.HelpBrowserMode,
+                           ConfigurationWidget.TrayStarterMode,
+                           ConfigurationWidget.HexEditorMode,
+                           ConfigurationWidget.WebBrowserMode]:
+            self.configListSearch.hide()
+        
+        if displayMode not in [ConfigurationWidget.TrayStarterMode,
+                               ConfigurationWidget.HexEditorMode]:
             self.__initLexers()
         
     def accept(self):
@@ -801,6 +924,16 @@ class ConfigurationWidget(QWidget):
         pageName = item.data(0, Qt.UserRole)
         if pageName not in self.__expandedEntries:
             self.__expandedEntries.append(pageName)
+    
+    def isUsingWebEngine(self):
+        """
+        Public method to get an indication, if QtWebEngine is being used.
+        
+        @return flag indicating the use of QtWebEngine
+        @rtype bool
+        """
+        return self.__webEngine or \
+            self.displayMode == ConfigurationWidget.WebBrowserMode
 
 
 class ConfigurationDialog(QDialog):
@@ -817,10 +950,12 @@ class ConfigurationDialog(QDialog):
     DefaultMode = ConfigurationWidget.DefaultMode
     HelpBrowserMode = ConfigurationWidget.HelpBrowserMode
     TrayStarterMode = ConfigurationWidget.TrayStarterMode
+    HexEditorMode = ConfigurationWidget.HexEditorMode
+    WebBrowserMode = ConfigurationWidget.WebBrowserMode
     
     def __init__(self, parent=None, name=None, modal=False,
                  fromEric=True, displayMode=ConfigurationWidget.DefaultMode,
-                 expandedEntries=[]):
+                 expandedEntries=None, webEngine=False):
         """
         Constructor
         
@@ -830,9 +965,11 @@ class ConfigurationDialog(QDialog):
         @keyparam fromEric flag indicating a dialog generation from within the
             eric6 ide (boolean)
         @keyparam displayMode mode of the configuration dialog
-            (DefaultMode, HelpBrowserMode, TrayStarterMode)
+            (DefaultMode, HelpBrowserMode, TrayStarterMode, HexEditorMode,
+             WebBrowserMode)
         @keyparam expandedEntries list of entries to be shown expanded
             (list of strings)
+        @keyparam webEngine flag indicating QtWebEngine is used (bool)
         """
         super(ConfigurationDialog, self).__init__(parent)
         if name:
@@ -846,7 +983,8 @@ class ConfigurationDialog(QDialog):
         
         self.cw = ConfigurationWidget(self, fromEric=fromEric,
                                       displayMode=displayMode,
-                                      expandedEntries=expandedEntries)
+                                      expandedEntries=expandedEntries,
+                                      webEngine=webEngine)
         size = self.cw.size()
         self.layout.addWidget(self.cw)
         self.resize(size)
@@ -914,15 +1052,17 @@ class ConfigurationWindow(E5MainWindow):
     """
     Main window class for the standalone dialog.
     """
-    def __init__(self, parent=None):
+    def __init__(self, parent=None, webEngine=False):
         """
         Constructor
         
         @param parent reference to the parent widget (QWidget)
+        @keyparam webEngine flag indicating QtWebEngine is used (bool)
         """
         super(ConfigurationWindow, self).__init__(parent)
         
-        self.cw = ConfigurationWidget(self, fromEric=False)
+        self.cw = ConfigurationWidget(self, fromEric=False,
+                                      webEngine=webEngine)
         size = self.cw.size()
         self.setCentralWidget(self.cw)
         self.resize(size)
