@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -318,14 +318,14 @@ class TemplateEntry(QTreeWidgetItem):
         for line in txt.splitlines():
             ind = line.find(var)
             if ind >= 0:
-                format = var[1:-1].split(':', 1)[1]
-                if format == 'rl':
+                variableFormat = var[1:-1].split(':', 1)[1]
+                if variableFormat == 'rl':
                     prefix = line[:ind]
                     postfix = line[ind + len(var):]
                     for v in val.splitlines():
                         t = "{0}{1}{2}{3}{4}".format(
                             t, os.linesep, prefix, v, postfix)
-                elif format == 'ml':
+                elif variableFormat == 'ml':
                     indent = line.replace(line.lstrip(), "")
                     prefix = line[:ind]
                     postfix = line[ind + len(var):]
@@ -688,27 +688,27 @@ class TemplateViewer(QTreeWidget):
             return
         
         ok = False
-        vars = itm.getVariables()
+        variables = itm.getVariables()
         varValues = self.__getPredefinedVars()
         
         # Remove predefined variables from list so user doesn't have to fill
         # these values out in the dialog.
         for v in list(varValues.keys()):
-            if v in vars:
-                vars.remove(v)
+            if v in variables:
+                variables.remove(v)
         
-        if vars:
+        if variables:
             if Preferences.getTemplates("SingleDialog"):
                 from .TemplateMultipleVariablesDialog import \
                     TemplateMultipleVariablesDialog
-                dlg = TemplateMultipleVariablesDialog(vars, self)
+                dlg = TemplateMultipleVariablesDialog(variables, self)
                 if dlg.exec_() == QDialog.Accepted:
                     varValues.update(dlg.getVariables())
                     ok = True
             else:
                 from .TemplateSingleVariableDialog import \
                     TemplateSingleVariableDialog
-                for var in vars:
+                for var in variables:
                     dlg = TemplateSingleVariableDialog(var, self)
                     if dlg.exec_() == QDialog.Accepted:
                         varValues[var] = dlg.getVariable()
