@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -37,7 +37,7 @@ class TRPreviewer(E5MainWindow):
     """
     Class implementing the UI Previewer main window.
     """
-    def __init__(self, filenames=[], parent=None, name=None):
+    def __init__(self, filenames=None, parent=None, name=None):
         """
         Constructor
         
@@ -120,7 +120,7 @@ class TRPreviewer(E5MainWindow):
         self.SAServer.loadTranslation.connect(self.translations.add)
         
         # defere loading of a UI file until we are shown
-        self.filesToLoad = filenames[:]
+        self.filesToLoad = [] if filenames is None else filenames[:]
         
     def show(self):
         """
@@ -721,7 +721,7 @@ class WidgetView(QWidget):
         
         try:
             self.__widget = uic.loadUi(self.__uiFileName)
-        except:
+        except Exception:
             pass
         
         if not self.__widget:
@@ -802,13 +802,13 @@ class WidgetArea(QMdiArea):
                 del wview
                 return
             
-            self.rebuildWidgets.connect(wview.buildWidget)  # __IGNORE_WARNING__
-            wview.installEventFilter(self)  # __IGNORE_WARNING__
+            self.rebuildWidgets.connect(wview.buildWidget)
+            wview.installEventFilter(self)
             
-            win = self.addSubWindow(wview)  # __IGNORE_WARNING__
+            win = self.addSubWindow(wview)
             self.widgets.append(win)
         
-        wview.showNormal()  # __IGNORE_WARNING__
+        wview.showNormal()
     
     def eventFilter(self, obj, ev):
         """
