@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -13,18 +13,18 @@ import os
 import time
 
 from PyQt5.QtCore import QFileInfo, QEvent, pyqtSlot
-from PyQt5.QtGui import QColor, QBrush, QTextCursor
+from PyQt5.QtGui import QTextCursor
 from PyQt5.QtWidgets import QWidget, QApplication, QDialogButtonBox
 
-from E5Gui.E5Completers import E5FileCompleter
 from E5Gui import E5MessageBox, E5FileDialog
 from E5Gui.E5MainWindow import E5MainWindow
+from E5Gui.E5PathPicker import E5PathPickerModes
 
 from .Ui_DiffDialog import Ui_DiffDialog
+from .DiffHighlighter import DiffHighlighter
 
 import Utilities
 import Preferences
-import UI.PixmapCache
 
 from difflib import SequenceMatcher
 
@@ -90,7 +90,10 @@ def unified_diff(a, b, fromfile='', tofile='', fromfiledate='',
             yield '--- {0}\t{1}{2}'.format(fromfile, fromfiledate, lineterm)
             yield '+++ {0}\t{1}{2}'.format(tofile, tofiledate, lineterm)
             started = True
-        i1, i2, j1, j2 = group[0][1], group[-1][2], group[0][3], group[-1][4]
+        i1 = group[0][1]
+        i2 = group[-1][2]
+        j1 = group[0][3]
+        j2 = group[-1][4]
         yield "@@ -{0:d},{1:d} +{2:d},{3:d} @@{4}".format(
             i1 + 1, i2 - i1, j1 + 1, j2 - j1, lineterm)
         for tag, i1, i2, j1, j2 in group:
@@ -213,11 +216,8 @@ class DiffDialog(QWidget, Ui_DiffDialog):
         super(DiffDialog, self).__init__(parent)
         self.setupUi(self)
         
-        self.file1Button.setIcon(UI.PixmapCache.getIcon("open.png"))
-        self.file2Button.setIcon(UI.PixmapCache.getIcon("open.png"))
-        
-        self.file1Completer = E5FileCompleter(self.file1Edit)
-        self.file2Completer = E5FileCompleter(self.file2Edit)
+        self.file1Picker.setMode(E5PathPickerModes.OpenFileMode)
+        self.file2Picker.setMode(E5PathPickerModes.OpenFileMode)
         
         self.diffButton = self.buttonBox.addButton(
             self.tr("Compare"), QDialogButtonBox.ActionRole)
@@ -231,6 +231,8 @@ class DiffDialog(QWidget, Ui_DiffDialog):
         self.saveButton.setEnabled(False)
         self.diffButton.setDefault(True)
         
+        self.searchWidget.attachTextEdit(self.contents)
+        
         self.filename1 = ''
         self.filename2 = ''
         
@@ -240,19 +242,11 @@ class DiffDialog(QWidget, Ui_DiffDialog):
         self.contents.setFontFamily(font.family())
         self.contents.setFontPointSize(font.pointSize())
         
-        self.cNormalFormat = self.contents.currentCharFormat()
-        self.cAddedFormat = self.contents.currentCharFormat()
-        self.cAddedFormat.setBackground(QBrush(QColor(190, 237, 190)))
-        self.cRemovedFormat = self.contents.currentCharFormat()
-        self.cRemovedFormat.setBackground(QBrush(QColor(237, 190, 190)))
-        self.cReplacedFormat = self.contents.currentCharFormat()
-        self.cReplacedFormat.setBackground(QBrush(QColor(190, 190, 237)))
-        self.cLineNoFormat = self.contents.currentCharFormat()
-        self.cLineNoFormat.setBackground(QBrush(QColor(255, 220, 168)))
+        self.highlighter = DiffHighlighter(self.contents.document())
         
         # connect some of our widgets explicitly
-        self.file1Edit.textChanged.connect(self.__fileChanged)
-        self.file2Edit.textChanged.connect(self.__fileChanged)
+        self.file1Picker.textChanged.connect(self.__fileChanged)
+        self.file2Picker.textChanged.connect(self.__fileChanged)
         
     def show(self, filename=None):
         """
@@ -261,7 +255,7 @@ class DiffDialog(QWidget, Ui_DiffDialog):
         @param filename name of a file to use as the first file (string)
         """
         if filename:
-            self.file1Edit.setText(filename)
+            self.file1Picker.setText(filename)
         super(DiffDialog, self).show()
         
     def on_buttonBox_clicked(self, button):
@@ -336,7 +330,7 @@ class DiffDialog(QWidget, Ui_DiffDialog):
         """
         Private slot to handle the Compare button press.
         """
-        self.filename1 = Utilities.toNativeSeparators(self.file1Edit.text())
+        self.filename1 = Utilities.toNativeSeparators(self.file1Picker.text())
         try:
             filemtime1 = time.ctime(os.stat(self.filename1).st_mtime)
         except IOError:
@@ -354,7 +348,7 @@ class DiffDialog(QWidget, Ui_DiffDialog):
                 .format(self.filename1))
             return
 
-        self.filename2 = Utilities.toNativeSeparators(self.file2Edit.text())
+        self.filename2 = Utilities.toNativeSeparators(self.file2Picker.text())
         try:
             filemtime2 = time.ctime(os.stat(self.filename2).st_mtime)
         except IOError:
@@ -391,17 +385,15 @@ class DiffDialog(QWidget, Ui_DiffDialog):
         
         self.saveButton.setEnabled(True)
 
-    def __appendText(self, txt, format):
+    def __appendText(self, txt):
         """
         Private method to append text to the end of the contents pane.
         
         @param txt text to insert (string)
-        @param format text format to be used (QTextCharFormat)
         """
         tc = self.contents.textCursor()
         tc.movePosition(QTextCursor.End)
         self.contents.setTextCursor(tc)
-        self.contents.setCurrentCharFormat(format)
         self.contents.insertPlainText(txt)
         
     def __generateUnifiedDiff(self, a, b, fromfile, tofile,
@@ -419,22 +411,13 @@ class DiffDialog(QWidget, Ui_DiffDialog):
         paras = 0
         for line in unified_diff(a, b, fromfile, tofile,
                                  fromfiledate, tofiledate):
-            if line.startswith('+') or line.startswith('>'):
-                format = self.cAddedFormat
-            elif line.startswith('-') or line.startswith('<'):
-                format = self.cRemovedFormat
-            elif line.startswith('@@'):
-                format = self.cLineNoFormat
-            else:
-                format = self.cNormalFormat
-            self.__appendText(line, format)
+            self.__appendText(line)
             paras += 1
             if not (paras % self.updateInterval):
                 QApplication.processEvents()
             
         if paras == 0:
-            self.__appendText(
-                self.tr('There is no difference.'), self.cNormalFormat)
+            self.__appendText(self.tr('There is no difference.'))
 
     def __generateContextDiff(self, a, b, fromfile, tofile,
                               fromfiledate, tofiledate):
@@ -451,66 +434,24 @@ class DiffDialog(QWidget, Ui_DiffDialog):
         paras = 0
         for line in context_diff(a, b, fromfile, tofile,
                                  fromfiledate, tofiledate):
-            if line.startswith('+ '):
-                format = self.cAddedFormat
-            elif line.startswith('- '):
-                format = self.cRemovedFormat
-            elif line.startswith('! '):
-                format = self.cReplacedFormat
-            elif (line.startswith('*** ') or line.startswith('--- ')) and \
-                    paras > 1:
-                format = self.cLineNoFormat
-            else:
-                format = self.cNormalFormat
-            self.__appendText(line, format)
+            self.__appendText(line)
             paras += 1
             if not (paras % self.updateInterval):
                 QApplication.processEvents()
             
         if paras == 0:
-            self.__appendText(
-                self.tr('There is no difference.'), self.cNormalFormat)
+            self.__appendText(self.tr('There is no difference.'))
 
     def __fileChanged(self):
         """
         Private slot to enable/disable the Compare button.
         """
-        if not self.file1Edit.text() or \
-           not self.file2Edit.text():
+        if not self.file1Picker.text() or \
+           not self.file2Picker.text():
             self.diffButton.setEnabled(False)
         else:
             self.diffButton.setEnabled(True)
 
-    def __selectFile(self, lineEdit):
-        """
-        Private slot to display a file selection dialog.
-        
-        @param lineEdit field for the display of the selected filename
-                (QLineEdit)
-        """
-        filename = E5FileDialog.getOpenFileName(
-            self,
-            self.tr("Select file to compare"),
-            lineEdit.text(),
-            "")
-            
-        if filename:
-            lineEdit.setText(Utilities.toNativeSeparators(filename))
-
-    @pyqtSlot()
-    def on_file1Button_clicked(self):
-        """
-        Private slot to handle the file 1 file selection button press.
-        """
-        self.__selectFile(self.file1Edit)
-
-    @pyqtSlot()
-    def on_file2Button_clicked(self):
-        """
-        Private slot to handle the file 2 file selection button press.
-        """
-        self.__selectFile(self.file2Edit)
-
 
 class DiffWindow(E5MainWindow):
     """
