@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 # This is the install script for eric6.
 
@@ -425,7 +425,7 @@ def createPyWrapper(pydir, wfile, isGuiScript=True):
     return wname
 
 
-def copyTree(src, dst, filters, excludeDirs=[], excludePatterns=[]):
+def copyTree(src, dst, filters, excludeDirs=None, excludePatterns=None):
     """
     Copy Python, translation, documentation, wizards configuration,
     designer template files and DTDs of a directory tree.
@@ -437,6 +437,10 @@ def copyTree(src, dst, filters, excludeDirs=[], excludePatterns=[]):
     @keyparam excludePatterns list of filter pattern determining the files to
         be skipped
     """
+    if excludeDirs is None:
+        excludeDirs = []
+    if excludePatterns is None:
+        excludePatterns = []
     try:
         names = os.listdir(src)
     except OSError:
@@ -452,8 +456,8 @@ def copyTree(src, dst, filters, excludeDirs=[], excludePatterns=[]):
         if not skipIt:
             srcname = os.path.join(src, name)
             dstname = os.path.join(dst, name)
-            for filter in filters:
-                if fnmatch.fnmatch(srcname, filter):
+            for fileFilter in filters:
+                if fnmatch.fnmatch(srcname, fileFilter):
                     if not os.path.isdir(dst):
                         os.makedirs(dst)
                     shutil.copy2(srcname, dstname)
@@ -478,7 +482,7 @@ def createGlobalPluginsDir():
             os.mkdir(pdir, 0o755)
         f = open(fname, "w")
         f.write(
-'''# -*- coding: utf-8 -*-
+            '''# -*- coding: utf-8 -*-
 
 """
 Package containing the global plugins.
@@ -551,7 +555,10 @@ def cleanUp():
                      "/usr/share/appdata/eric6" + marker + ".appdata.xml",
                      "/usr/share/metainfo/eric6" + marker + ".appdata.xml",
                      "/usr/share/applications/eric6_webbrowser" + marker +
-                     ".desktop"]:
+                     ".desktop",
+                     "/usr/share/applications/eric6_browser" + marker +
+                     ".desktop",
+                     ]:
             if os.path.exists(name):
                 os.remove(name)
     
@@ -567,7 +574,7 @@ def cleanUp():
         "eric6_plugininstall", "eric6_pluginuninstall",
         "eric6_pluginrepository", "eric6_sqlbrowser",
         "eric6_webbrowser", "eric6_iconeditor",
-        "eric6_snap",
+        "eric6_snap", "eric6_hexeditor", "eric6_browser",
     ]
     if includePythonVariant:
         marker = PythonMarkers[sys.version_info.major]
@@ -671,12 +678,13 @@ def installEric():
     for name in ["eric6_api", "eric6_doc"]:
         wnames.append(createPyWrapper(cfg['ericDir'], name, False))
     for name in ["eric6_compare", "eric6_configure", "eric6_diff",
-                 "eric6_editor", "eric6_iconeditor", "eric6_plugininstall",
-                 "eric6_pluginrepository", "eric6_pluginuninstall",
-                 "eric6_qregexp", "eric6_qregularexpression", "eric6_re",
-                 "eric6_snap", "eric6_sqlbrowser", "eric6_tray",
-                 "eric6_trpreviewer", "eric6_uipreviewer", "eric6_unittest",
-                 "eric6_webbrowser", "eric6"]:
+                 "eric6_editor", "eric6_hexeditor", "eric6_iconeditor",
+                 "eric6_plugininstall", "eric6_pluginrepository",
+                 "eric6_pluginuninstall", "eric6_qregexp",
+                 "eric6_qregularexpression", "eric6_re", "eric6_snap",
+                 "eric6_sqlbrowser", "eric6_tray", "eric6_trpreviewer",
+                 "eric6_uipreviewer", "eric6_unittest", "eric6_webbrowser",
+                 "eric6_browser", "eric6"]:
         wnames.append(createPyWrapper(cfg['ericDir'], name))
     
     # set install prefix, if not None
@@ -853,6 +861,10 @@ def installEric():
                 os.path.join(sourceDir, "eric6_webbrowser.desktop"),
                 os.path.join(dst, "eric6_webbrowser" + marker + ".desktop"),
                 marker)
+            copyDesktopFile(
+                os.path.join(sourceDir, "eric6_browser.desktop"),
+                os.path.join(dst, "eric6_browser" + marker + ".desktop"),
+                marker)
             dst = os.path.normpath(
                 os.path.join(distDir, "usr/share/metainfo"))
             if not os.path.exists(dst):
@@ -887,6 +899,11 @@ def installEric():
                 "/usr/share/applications/eric6_webbrowser" + marker +
                 ".desktop",
                 marker)
+            copyDesktopFile(
+                os.path.join(sourceDir, "eric6_browser.desktop"),
+                "/usr/share/applications/eric6_browser" + marker +
+                ".desktop",
+                marker)
     
     # Create a Mac application bundle
     if sys.platform == "darwin":
@@ -1076,15 +1093,19 @@ def createConfig():
         """    '''\n"""
         """    Module function to get a configuration value.\n"""
         """\n"""
-        """    @param name name of the configuration value (string)\n"""
+        """    @param name name of the configuration value"""
+        """    @type str\n"""
+        """    @exception AttributeError raised to indicate an invalid"""
+        """ config entry\n"""
         """    '''\n"""
         """    try:\n"""
         """        return _pkg_config[name]\n"""
         """    except KeyError:\n"""
         """        pass\n"""
         """\n"""
-        """    raise AttributeError('"{{0}}" is not a valid configuration"""
-        """ value'.format(name))\n"""
+        """    raise AttributeError(\n"""
+        """        '"{{0}}" is not a valid configuration value'"""
+        """.format(name))\n"""
     ).format(
         cfg['ericDir'], cfg['ericPixDir'], cfg['ericIconDir'],
         cfg['ericDTDDir'], cfg['ericCSSDir'],
@@ -1093,7 +1114,7 @@ def createConfig():
         cfg['ericTemplatesDir'],
         cfg['ericCodeTemplatesDir'], cfg['ericOthersDir'],
         cfg['bindir'], cfg['mdir'],
-        cfg['apidir'], apis,
+        cfg['apidir'], sorted(apis),
         macAppBundlePath, macAppBundleName,
     )
     copyToFile(fn, config)
@@ -1107,12 +1128,12 @@ def doDependancyChecks():
     
     # perform dependency checks
     print("Python Version: {0:d}.{1:d}.{2:d}".format(*sys.version_info[:3]))
-    if sys.version_info < (2, 7, 0):
-        print('Sorry, you must have Python 2.7.0 or higher or '
-              'Python 3.3.0 or higher.')
+    if sys.version_info < (2, 7, 10):
+        print('Sorry, you must have Python 2.7.10 or higher or '
+              'Python 3.4.0 or higher.')
         exit(5)
-    elif sys.version_info < (3, 3, 0) and sys.version_info[0] == 3:
-        print('Sorry, you must have Python 3.3.0 or higher.')
+    elif sys.version_info < (3, 4, 0) and sys.version_info[0] == 3:
+        print('Sorry, you must have Python 3.4.0 or higher.')
         exit(5)
     if sys.version_info > (3, 9, 9):
         print('Sorry, eric6 requires Python 3 or Python 2 for running.')
@@ -1218,12 +1239,12 @@ def doDependancyChecks():
         if "snapshot" not in sipVersion and "dev" not in sipVersion:
             while sipVersion.count('.') < 2:
                 sipVersion += '.0'
-            (maj, min, pat) = sipVersion.split('.')
-            maj = int(maj)
-            min = int(min)
+            (major, minor, pat) = sipVersion.split('.')
+            major = int(major)
+            minor = int(minor)
             pat = int(pat)
-            if maj < 4 or (maj == 4 and min < 14) or \
-                    (maj == 4 and min == 14 and pat < 2):
+            if major < 4 or (major == 4 and minor < 14) or \
+                    (major == 4 and minor == 14 and pat < 2):
                 print('Sorry, you must have sip 4.14.2 or higher or'
                       ' a recent snapshot release.')
                 exit(3)
@@ -1249,13 +1270,13 @@ def doDependancyChecks():
     if "snapshot" not in pyqtVersion and "dev" not in pyqtVersion:
         while pyqtVersion.count('.') < 2:
             pyqtVersion += '.0'
-        (maj, min, pat) = pyqtVersion.split('.')
-        maj = int(maj)
-        min = int(min)
+        (major, minor, pat) = pyqtVersion.split('.')
+        major = int(major)
+        minor = int(minor)
         pat = int(pat)
-        if maj < 4 or \
-            (maj == 4 and min < 10) or \
-                (maj == 5 and min < 3):
+        if major < 4 or \
+            (major == 4 and minor < 10) or \
+                (major == 5 and minor < 3):
             print('Sorry, you must have PyQt 4.10.0 or better or')
             print('PyQt 5.3.0 or better or'
                   ' a recent snapshot release.')
@@ -1279,11 +1300,11 @@ def doDependancyChecks():
     if "snapshot" not in scintillaVersion and "dev" not in scintillaVersion:
         while scintillaVersion.count('.') < 2:
             scintillaVersion += '.0'
-        (maj, min, pat) = scintillaVersion.split('.')
-        maj = int(maj)
-        min = int(min)
+        (major, minor, pat) = scintillaVersion.split('.')
+        major = int(major)
+        minor = int(minor)
         pat = int(pat)
-        if maj < 2 or (maj == 2 and min < 8):
+        if major < 2 or (major == 2 and minor < 8):
             print('Sorry, you must have QScintilla 2.8.0 or higher or'
                   ' a recent snapshot release.')
             exit(5)
@@ -1432,7 +1453,7 @@ def main(argv):
                     print("The configuration dictionary in '{0}' is incorrect."
                           " Aborting".format(arg))
                     exit(6)
-            except:
+            except Exception:
                 cfg = {}
         elif opt == "-m":
             macAppBundleName = arg
@@ -1509,11 +1530,8 @@ def main(argv):
     
     if doCompile:
         print("\nCompiling source files ...")
-        if sys.version_info[0] == 3:
-            skipRe = re.compile(r"DebugClients[\\/]Python[\\/]")
-        else:
-            skipRe = re.compile(r"DebugClients[\\/]Python3[\\/]")
         # Hide compile errors (mainly because of Py2/Py3 differences)
+        skipRe = re.compile(r"DebugClients[\\/]Python[\\/]")
         sys.stdout = io.StringIO()
         if distDir:
             compileall.compile_dir(
@@ -1567,8 +1585,11 @@ if __name__ == "__main__":
         main(sys.argv)
     except SystemExit:
         raise
-    except:
+    except Exception:
         print("""An internal error occured.  Please report all the output"""
               """ of the program,\nincluding the following traceback, to"""
               """ eric-bugs@eric-ide.python-projects.org.\n""")
         raise
+
+#
+# eflag: noqa = M801
